[FFmpeg-devel] [PATCH] lavu/cpu: Use consistent av_cpu_ prefix for all functions

Thilo Borgmann thilo.borgmann at mail.de
Mon Jul 19 23:43:33 EEST 2021


Hi,

as requested in review of [1]. Does this require some version bump?

Thanks,
Thilo

[1] [PATCH] fftools/cmdutils.c: Add cmd line option to override detection of cpu count
-------------- next part --------------
From 7b7659db29240b0ee48b469987546a793fcfa3b1 Mon Sep 17 00:00:00 2001
From: Thilo Borgmann <thilo.borgmann at mail.de>
Date: Mon, 19 Jul 2021 22:40:07 +0200
Subject: [PATCH] lavu/cpu: Use consistent av_cpu_ prefix for all functions

---
 fftools/cmdutils.c                          |  8 ++++----
 libavcodec/x86/aacencdsp_init.c             |  2 +-
 libavcodec/x86/aacpsdsp_init.c              |  2 +-
 libavcodec/x86/ac3dsp_init.c                |  4 ++--
 libavcodec/x86/alacdsp_init.c               |  2 +-
 libavcodec/x86/audiodsp_init.c              |  2 +-
 libavcodec/x86/blockdsp_init.c              |  2 +-
 libavcodec/x86/bswapdsp_init.c              |  2 +-
 libavcodec/x86/cavsdsp.c                    |  2 +-
 libavcodec/x86/celt_pvq_init.c              |  2 +-
 libavcodec/x86/cfhddsp_init.c               |  2 +-
 libavcodec/x86/cfhdencdsp_init.c            |  2 +-
 libavcodec/x86/dcadsp_init.c                |  2 +-
 libavcodec/x86/dct_init.c                   |  2 +-
 libavcodec/x86/dirac_dwt_init.c             |  2 +-
 libavcodec/x86/diracdsp_init.c              |  2 +-
 libavcodec/x86/dnxhdenc_init.c              |  2 +-
 libavcodec/x86/exrdsp_init.c                |  2 +-
 libavcodec/x86/fdctdsp_init.c               |  2 +-
 libavcodec/x86/fft_init.c                   |  2 +-
 libavcodec/x86/flacdsp_init.c               |  2 +-
 libavcodec/x86/fmtconvert_init.c            |  2 +-
 libavcodec/x86/g722dsp_init.c               |  2 +-
 libavcodec/x86/h263dsp_init.c               |  2 +-
 libavcodec/x86/h264_intrapred_init.c        |  2 +-
 libavcodec/x86/h264_qpel.c                  |  2 +-
 libavcodec/x86/h264chroma_init.c            |  2 +-
 libavcodec/x86/h264dsp_init.c               |  2 +-
 libavcodec/x86/hevcdsp_init.c               |  2 +-
 libavcodec/x86/hpeldsp_init.c               |  2 +-
 libavcodec/x86/huffyuvdsp_init.c            |  2 +-
 libavcodec/x86/huffyuvencdsp_init.c         |  2 +-
 libavcodec/x86/idctdsp_init.c               |  2 +-
 libavcodec/x86/jpeg2000dsp_init.c           |  2 +-
 libavcodec/x86/lossless_audiodsp_init.c     |  2 +-
 libavcodec/x86/lossless_videodsp_init.c     |  2 +-
 libavcodec/x86/lossless_videoencdsp_init.c  |  2 +-
 libavcodec/x86/lpc.c                        |  2 +-
 libavcodec/x86/mdct15_init.c                |  2 +-
 libavcodec/x86/me_cmp_init.c                |  2 +-
 libavcodec/x86/mlpdsp_init.c                |  2 +-
 libavcodec/x86/mpegaudiodsp.c               |  2 +-
 libavcodec/x86/mpegvideo.c                  |  2 +-
 libavcodec/x86/mpegvideodsp.c               |  2 +-
 libavcodec/x86/mpegvideoenc.c               |  2 +-
 libavcodec/x86/mpegvideoencdsp_init.c       |  2 +-
 libavcodec/x86/opusdsp_init.c               |  2 +-
 libavcodec/x86/pixblockdsp_init.c           |  2 +-
 libavcodec/x86/pngdsp_init.c                |  2 +-
 libavcodec/x86/proresdsp_init.c             |  2 +-
 libavcodec/x86/qpeldsp_init.c               |  2 +-
 libavcodec/x86/rv34dsp_init.c               |  2 +-
 libavcodec/x86/rv40dsp_init.c               |  2 +-
 libavcodec/x86/sbcdsp_init.c                |  2 +-
 libavcodec/x86/sbrdsp_init.c                |  2 +-
 libavcodec/x86/snowdsp.c                    |  2 +-
 libavcodec/x86/svq1enc_init.c               |  2 +-
 libavcodec/x86/synth_filter_init.c          |  2 +-
 libavcodec/x86/takdsp_init.c                |  2 +-
 libavcodec/x86/ttadsp_init.c                |  2 +-
 libavcodec/x86/ttaencdsp_init.c             |  2 +-
 libavcodec/x86/utvideodsp_init.c            |  2 +-
 libavcodec/x86/v210-init.c                  |  2 +-
 libavcodec/x86/v210enc_init.c               |  2 +-
 libavcodec/x86/vc1dsp_init.c                |  2 +-
 libavcodec/x86/videodsp_init.c              |  2 +-
 libavcodec/x86/vorbisdsp_init.c             |  2 +-
 libavcodec/x86/vp3dsp_init.c                |  2 +-
 libavcodec/x86/vp6dsp_init.c                |  2 +-
 libavcodec/x86/vp8dsp_init.c                |  4 ++--
 libavcodec/x86/vp9dsp_init.c                |  2 +-
 libavcodec/x86/vp9dsp_init_16bpp.c          |  2 +-
 libavcodec/x86/vp9dsp_init_16bpp_template.c |  2 +-
 libavcodec/x86/xvididct_init.c              |  2 +-
 libavfilter/x86/af_afir_init.c              |  2 +-
 libavfilter/x86/af_anlmdn_init.c            |  2 +-
 libavfilter/x86/af_volume_init.c            |  2 +-
 libavfilter/x86/avf_showcqt_init.c          |  2 +-
 libavfilter/x86/colorspacedsp_init.c        |  2 +-
 libavfilter/x86/scene_sad_init.c            |  2 +-
 libavfilter/x86/vf_atadenoise_init.c        |  2 +-
 libavfilter/x86/vf_blend_init.c             |  2 +-
 libavfilter/x86/vf_bwdif_init.c             |  2 +-
 libavfilter/x86/vf_convolution_init.c       |  2 +-
 libavfilter/x86/vf_framerate_init.c         |  2 +-
 libavfilter/x86/vf_gblur_init.c             |  2 +-
 libavfilter/x86/vf_gradfun_init.c           |  2 +-
 libavfilter/x86/vf_hflip_init.c             |  2 +-
 libavfilter/x86/vf_idet_init.c              |  2 +-
 libavfilter/x86/vf_limiter_init.c           |  2 +-
 libavfilter/x86/vf_maskedclamp_init.c       |  2 +-
 libavfilter/x86/vf_maskedmerge_init.c       |  2 +-
 libavfilter/x86/vf_noise.c                  |  2 +-
 libavfilter/x86/vf_overlay_init.c           |  2 +-
 libavfilter/x86/vf_psnr_init.c              |  2 +-
 libavfilter/x86/vf_ssim_init.c              |  2 +-
 libavfilter/x86/vf_threshold_init.c         |  2 +-
 libavfilter/x86/vf_transpose_init.c         |  2 +-
 libavfilter/x86/vf_v360_init.c              |  2 +-
 libavfilter/x86/vf_w3fdif_init.c            |  2 +-
 libavfilter/x86/vf_yadif_init.c             |  2 +-
 libavutil/cpu.c                             |  8 ++++----
 libavutil/cpu.h                             | 12 ++++++------
 libavutil/x86/cpu.c                         |  2 +-
 libavutil/x86/fixed_dsp_init.c              |  2 +-
 libavutil/x86/float_dsp_init.c              |  2 +-
 libavutil/x86/imgutils_init.c               |  2 +-
 libavutil/x86/lls_init.c                    |  2 +-
 libavutil/x86/pixelutils_init.c             |  2 +-
 libavutil/x86/tx_float_init.c               |  2 +-
 libswresample/resample.c                    |  2 +-
 libswresample/x86/audio_convert_init.c      |  2 +-
 libswresample/x86/rematrix_init.c           |  2 +-
 libswresample/x86/resample_init.c           |  2 +-
 libswscale/swscale.c                        |  4 ++--
 libswscale/utils.c                          |  2 +-
 libswscale/x86/rgb2rgb.c                    |  2 +-
 libswscale/x86/swscale.c                    |  2 +-
 libswscale/x86/yuv2rgb.c                    |  2 +-
 119 files changed, 133 insertions(+), 133 deletions(-)

diff --git a/fftools/cmdutils.c b/fftools/cmdutils.c
index 6e875104fd..fb4f1eb6b7 100644
--- a/fftools/cmdutils.c
+++ b/fftools/cmdutils.c
@@ -845,12 +845,12 @@ do {                                                                           \
 int opt_cpuflags(void *optctx, const char *opt, const char *arg)
 {
     int ret;
-    unsigned flags = av_get_cpu_flags();
+    unsigned flags = av_cpu_get_flags();
 
-    if ((ret = av_parse_cpu_caps(&flags, arg)) < 0)
+    if ((ret = av_cpu_parse_caps(&flags, arg)) < 0)
         return ret;
 
-    av_force_cpu_flags(flags);
+    av_cpu_force_flags(flags);
     return 0;
 }
 
@@ -874,7 +874,7 @@ int opt_cpucount(void *optctx, const char *opt, const char *arg)
     ret = av_opt_eval_int(&pclass, opts, arg, &count);
 
     if (!ret) {
-        av_force_cpu_count(count);
+        av_cpu_force_count(count);
     }
 
     return ret;
diff --git a/libavcodec/x86/aacencdsp_init.c b/libavcodec/x86/aacencdsp_init.c
index 049a2417d9..aa7ab687d9 100644
--- a/libavcodec/x86/aacencdsp_init.c
+++ b/libavcodec/x86/aacencdsp_init.c
@@ -34,7 +34,7 @@ void ff_aac_quantize_bands_sse2(int *out, const float *in, const float *scaled,
 
 av_cold void ff_aac_dsp_init_x86(AACEncContext *s)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_SSE(cpu_flags))
         s->abs_pow34   = ff_abs_pow34_sse;
diff --git a/libavcodec/x86/aacpsdsp_init.c b/libavcodec/x86/aacpsdsp_init.c
index 21f00efa24..8b4dd67aee 100644
--- a/libavcodec/x86/aacpsdsp_init.c
+++ b/libavcodec/x86/aacpsdsp_init.c
@@ -51,7 +51,7 @@ void ff_ps_hybrid_analysis_ileave_sse(float (*out)[32][2], float L[2][38][64],
 
 av_cold void ff_psdsp_init_x86(PSDSPContext *s)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_SSE(cpu_flags)) {
         s->add_squares            = ff_ps_add_squares_sse;
diff --git a/libavcodec/x86/ac3dsp_init.c b/libavcodec/x86/ac3dsp_init.c
index 2ae762af46..79fd15ece0 100644
--- a/libavcodec/x86/ac3dsp_init.c
+++ b/libavcodec/x86/ac3dsp_init.c
@@ -41,7 +41,7 @@ void ff_ac3_extract_exponents_ssse3(uint8_t *exp, int32_t *coef, int nb_coefs);
 
 av_cold void ff_ac3dsp_init_x86(AC3DSPContext *c, int bit_exact)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_MMX(cpu_flags)) {
         c->ac3_exponent_min = ff_ac3_exponent_min_mmx;
@@ -88,7 +88,7 @@ DOWNMIX_FUNCS(fma3)
 
 void ff_ac3dsp_set_downmix_x86(AC3DSPContext *c)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
 #define SET_DOWNMIX(ch, suf, SUF)                                       \
     if (ch == c->in_channels) {                                         \
diff --git a/libavcodec/x86/alacdsp_init.c b/libavcodec/x86/alacdsp_init.c
index 18f7308a12..9aca7b788a 100644
--- a/libavcodec/x86/alacdsp_init.c
+++ b/libavcodec/x86/alacdsp_init.c
@@ -31,7 +31,7 @@ void ff_alac_append_extra_bits_mono_sse2(int32_t *buffer[2], int32_t *extra_bits
 av_cold void ff_alacdsp_init_x86(ALACDSPContext *c)
 {
 #if HAVE_X86ASM
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_SSE2(cpu_flags)) {
         c->append_extra_bits[0] = ff_alac_append_extra_bits_mono_sse2;
diff --git a/libavcodec/x86/audiodsp_init.c b/libavcodec/x86/audiodsp_init.c
index 98e296c264..5f1a7c398e 100644
--- a/libavcodec/x86/audiodsp_init.c
+++ b/libavcodec/x86/audiodsp_init.c
@@ -42,7 +42,7 @@ void ff_vector_clipf_sse(float *dst, const float *src,
 
 av_cold void ff_audiodsp_init_x86(AudioDSPContext *c)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_MMX(cpu_flags))
         c->vector_clip_int32 = ff_vector_clip_int32_mmx;
diff --git a/libavcodec/x86/blockdsp_init.c b/libavcodec/x86/blockdsp_init.c
index 8b01a447cd..42de8d75e3 100644
--- a/libavcodec/x86/blockdsp_init.c
+++ b/libavcodec/x86/blockdsp_init.c
@@ -37,7 +37,7 @@ av_cold void ff_blockdsp_init_x86(BlockDSPContext *c,
                                   AVCodecContext *avctx)
 {
 #if HAVE_X86ASM
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_MMX(cpu_flags)) {
         c->clear_block  = ff_clear_block_mmx;
diff --git a/libavcodec/x86/bswapdsp_init.c b/libavcodec/x86/bswapdsp_init.c
index 877bab1a2c..b62d32fb80 100644
--- a/libavcodec/x86/bswapdsp_init.c
+++ b/libavcodec/x86/bswapdsp_init.c
@@ -29,7 +29,7 @@ void ff_bswap32_buf_avx2(uint32_t *dst, const uint32_t *src, int w);
 
 av_cold void ff_bswapdsp_init_x86(BswapDSPContext *c)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_SSE2(cpu_flags))
         c->bswap_buf = ff_bswap32_buf_sse2;
diff --git a/libavcodec/x86/cavsdsp.c b/libavcodec/x86/cavsdsp.c
index f974f93fc0..61a887f729 100644
--- a/libavcodec/x86/cavsdsp.c
+++ b/libavcodec/x86/cavsdsp.c
@@ -429,7 +429,7 @@ static av_cold void cavsdsp_init_3dnow(CAVSDSPContext *c,
 
 av_cold void ff_cavsdsp_init_x86(CAVSDSPContext *c, AVCodecContext *avctx)
 {
-    av_unused int cpu_flags = av_get_cpu_flags();
+    av_unused int cpu_flags = av_cpu_get_flags();
 
     if (X86_MMX(cpu_flags))
         cavsdsp_init_mmx(c, avctx);
diff --git a/libavcodec/x86/celt_pvq_init.c b/libavcodec/x86/celt_pvq_init.c
index 5a0669e6f2..2b71fc7f10 100644
--- a/libavcodec/x86/celt_pvq_init.c
+++ b/libavcodec/x86/celt_pvq_init.c
@@ -31,7 +31,7 @@ extern float ff_pvq_search_exact_avx  (float *X, int *y, int K, int N);
 
 av_cold void ff_celt_pvq_init_x86(CeltPVQ *s)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_SSE2(cpu_flags))
         s->pvq_search = ff_pvq_search_approx_sse2;
diff --git a/libavcodec/x86/cfhddsp_init.c b/libavcodec/x86/cfhddsp_init.c
index ab7ff83087..a9f6a8d51e 100644
--- a/libavcodec/x86/cfhddsp_init.c
+++ b/libavcodec/x86/cfhddsp_init.c
@@ -39,7 +39,7 @@ void ff_cfhd_horiz_filter_clip12_sse2(int16_t *output, const int16_t *low, const
 
 av_cold void ff_cfhddsp_init_x86(CFHDDSPContext *c, int depth, int bayer)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_SSE2(cpu_flags)) {
         c->horiz_filter = ff_cfhd_horiz_filter_sse2;
diff --git a/libavcodec/x86/cfhdencdsp_init.c b/libavcodec/x86/cfhdencdsp_init.c
index 28f1dd504d..8299e49dd2 100644
--- a/libavcodec/x86/cfhdencdsp_init.c
+++ b/libavcodec/x86/cfhdencdsp_init.c
@@ -37,7 +37,7 @@ void ff_cfhdenc_vert_filter_sse2(int16_t *input, int16_t *low, int16_t *high,
 
 av_cold void ff_cfhdencdsp_init_x86(CFHDEncDSPContext *c)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
 #if ARCH_X86_64
     if (EXTERNAL_SSE2(cpu_flags)) {
diff --git a/libavcodec/x86/dcadsp_init.c b/libavcodec/x86/dcadsp_init.c
index fc10fb8bc5..4d64deba53 100644
--- a/libavcodec/x86/dcadsp_init.c
+++ b/libavcodec/x86/dcadsp_init.c
@@ -35,7 +35,7 @@ LFE_FIR_FLOAT_FUNC(fma3)
 
 av_cold void ff_dcadsp_init_x86(DCADSPContext *s)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (ARCH_X86_32 && EXTERNAL_SSE(cpu_flags))
         s->lfe_fir_float[0] = ff_lfe_fir0_float_sse;
diff --git a/libavcodec/x86/dct_init.c b/libavcodec/x86/dct_init.c
index c31ef92238..d3a81d6c29 100644
--- a/libavcodec/x86/dct_init.c
+++ b/libavcodec/x86/dct_init.c
@@ -28,7 +28,7 @@ void ff_dct32_float_avx(FFTSample *out, const FFTSample *in);
 
 av_cold void ff_dct_init_x86(DCTContext *s)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
 #if ARCH_X86_32
     if (EXTERNAL_SSE(cpu_flags))
diff --git a/libavcodec/x86/dirac_dwt_init.c b/libavcodec/x86/dirac_dwt_init.c
index 49a6380add..a715367bd0 100644
--- a/libavcodec/x86/dirac_dwt_init.c
+++ b/libavcodec/x86/dirac_dwt_init.c
@@ -161,7 +161,7 @@ static void horizontal_compose_dd97i_ssse3(uint8_t *_b, uint8_t *_tmp, int w)
 void ff_spatial_idwt_init_x86(DWTContext *d, enum dwt_type type)
 {
 #if HAVE_X86ASM
-  int mm_flags = av_get_cpu_flags();
+  int mm_flags = av_cpu_get_flags();
 
 #if !ARCH_X86_64
     if (!(mm_flags & AV_CPU_FLAG_MMX))
diff --git a/libavcodec/x86/diracdsp_init.c b/libavcodec/x86/diracdsp_init.c
index 8baacf3129..fad0c84810 100644
--- a/libavcodec/x86/diracdsp_init.c
+++ b/libavcodec/x86/diracdsp_init.c
@@ -104,7 +104,7 @@ HPEL_FILTER(16, sse2)
 void ff_diracdsp_init_x86(DiracDSPContext* c)
 {
 #if HAVE_X86ASM
-    int mm_flags = av_get_cpu_flags();
+    int mm_flags = av_cpu_get_flags();
 
     if (EXTERNAL_MMX(mm_flags)) {
         c->add_dirac_obmc[0] = ff_add_dirac_obmc8_mmx;
diff --git a/libavcodec/x86/dnxhdenc_init.c b/libavcodec/x86/dnxhdenc_init.c
index fd6f15005a..cfee4d1802 100644
--- a/libavcodec/x86/dnxhdenc_init.c
+++ b/libavcodec/x86/dnxhdenc_init.c
@@ -30,7 +30,7 @@ void ff_get_pixels_8x4_sym_sse2(int16_t *block, const uint8_t *pixels,
 
 av_cold void ff_dnxhdenc_init_x86(DNXHDEncContext *ctx)
 {
-    if (EXTERNAL_SSE2(av_get_cpu_flags())) {
+    if (EXTERNAL_SSE2(av_cpu_get_flags())) {
         if (ctx->cid_table->bit_depth == 8)
             ctx->get_pixels_8x4_sym = ff_get_pixels_8x4_sym_sse2;
     }
diff --git a/libavcodec/x86/exrdsp_init.c b/libavcodec/x86/exrdsp_init.c
index 63b3480d8f..6c2be56619 100644
--- a/libavcodec/x86/exrdsp_init.c
+++ b/libavcodec/x86/exrdsp_init.c
@@ -34,7 +34,7 @@ void ff_predictor_avx2(uint8_t *src, ptrdiff_t size);
 
 av_cold void ff_exrdsp_init_x86(ExrDSPContext *dsp)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_SSE2(cpu_flags)) {
         dsp->reorder_pixels = ff_reorder_pixels_sse2;
diff --git a/libavcodec/x86/fdctdsp_init.c b/libavcodec/x86/fdctdsp_init.c
index 0cb5fd625b..3eb21fb62e 100644
--- a/libavcodec/x86/fdctdsp_init.c
+++ b/libavcodec/x86/fdctdsp_init.c
@@ -26,7 +26,7 @@
 av_cold void ff_fdctdsp_init_x86(FDCTDSPContext *c, AVCodecContext *avctx,
                                  unsigned high_bit_depth)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
     const int dct_algo = avctx->dct_algo;
 
     if (!high_bit_depth) {
diff --git a/libavcodec/x86/fft_init.c b/libavcodec/x86/fft_init.c
index 928f1dcda7..811bb59860 100644
--- a/libavcodec/x86/fft_init.c
+++ b/libavcodec/x86/fft_init.c
@@ -26,7 +26,7 @@
 
 av_cold void ff_fft_init_x86(FFTContext *s)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (s->nbits > 16)
         return;
diff --git a/libavcodec/x86/flacdsp_init.c b/libavcodec/x86/flacdsp_init.c
index 6315b6903e..b6992f0b55 100644
--- a/libavcodec/x86/flacdsp_init.c
+++ b/libavcodec/x86/flacdsp_init.c
@@ -55,7 +55,7 @@ av_cold void ff_flacdsp_init_x86(FLACDSPContext *c, enum AVSampleFormat fmt, int
                                  int bps)
 {
 #if HAVE_X86ASM
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
 #if CONFIG_FLAC_DECODER
     if (EXTERNAL_SSE2(cpu_flags)) {
diff --git a/libavcodec/x86/fmtconvert_init.c b/libavcodec/x86/fmtconvert_init.c
index df097054e4..63058ff9e1 100644
--- a/libavcodec/x86/fmtconvert_init.c
+++ b/libavcodec/x86/fmtconvert_init.c
@@ -41,7 +41,7 @@ void ff_int32_to_float_fmul_array8_sse2(FmtConvertContext *c, float *dst, const
 av_cold void ff_fmt_convert_init_x86(FmtConvertContext *c, AVCodecContext *avctx)
 {
 #if HAVE_X86ASM
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_SSE(cpu_flags)) {
         c->int32_to_float_fmul_scalar = ff_int32_to_float_fmul_scalar_sse;
diff --git a/libavcodec/x86/g722dsp_init.c b/libavcodec/x86/g722dsp_init.c
index 614695193b..f33327c5f2 100644
--- a/libavcodec/x86/g722dsp_init.c
+++ b/libavcodec/x86/g722dsp_init.c
@@ -28,7 +28,7 @@ void ff_g722_apply_qmf_sse2(const int16_t *prev_samples, int xout[2]);
 
 av_cold void ff_g722dsp_init_x86(G722DSPContext *dsp)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_SSE2(cpu_flags))
         dsp->apply_qmf = ff_g722_apply_qmf_sse2;
diff --git a/libavcodec/x86/h263dsp_init.c b/libavcodec/x86/h263dsp_init.c
index ab81063233..350d8151b7 100644
--- a/libavcodec/x86/h263dsp_init.c
+++ b/libavcodec/x86/h263dsp_init.c
@@ -30,7 +30,7 @@ void ff_h263_v_loop_filter_mmx(uint8_t *src, int stride, int qscale);
 
 av_cold void ff_h263dsp_init_x86(H263DSPContext *c)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_MMX(cpu_flags)) {
         c->h263_h_loop_filter = ff_h263_h_loop_filter_mmx;
diff --git a/libavcodec/x86/h264_intrapred_init.c b/libavcodec/x86/h264_intrapred_init.c
index bdd5125d68..6f23192229 100644
--- a/libavcodec/x86/h264_intrapred_init.c
+++ b/libavcodec/x86/h264_intrapred_init.c
@@ -186,7 +186,7 @@ av_cold void ff_h264_pred_init_x86(H264PredContext *h, int codec_id,
                                    const int bit_depth,
                                    const int chroma_format_idc)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (bit_depth == 8) {
         if (EXTERNAL_MMX(cpu_flags)) {
diff --git a/libavcodec/x86/h264_qpel.c b/libavcodec/x86/h264_qpel.c
index a2d8a64976..71327de3a1 100644
--- a/libavcodec/x86/h264_qpel.c
+++ b/libavcodec/x86/h264_qpel.c
@@ -542,7 +542,7 @@ av_cold void ff_h264qpel_init_x86(H264QpelContext *c, int bit_depth)
 {
 #if HAVE_X86ASM
     int high_bit_depth = bit_depth > 8;
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_MMXEXT(cpu_flags)) {
         if (!high_bit_depth) {
diff --git a/libavcodec/x86/h264chroma_init.c b/libavcodec/x86/h264chroma_init.c
index 36bf29df02..28d5b00beb 100644
--- a/libavcodec/x86/h264chroma_init.c
+++ b/libavcodec/x86/h264chroma_init.c
@@ -70,7 +70,7 @@ CHROMA_MC(avg, 8, 10, avx)
 av_cold void ff_h264chroma_init_x86(H264ChromaContext *c, int bit_depth)
 {
     int high_bit_depth = bit_depth > 8;
-    int cpu_flags      = av_get_cpu_flags();
+    int cpu_flags      = av_cpu_get_flags();
 
     if (EXTERNAL_MMX(cpu_flags) && !high_bit_depth) {
         c->put_h264_chroma_pixels_tab[0] = ff_put_h264_chroma_mc8_rnd_mmx;
diff --git a/libavcodec/x86/h264dsp_init.c b/libavcodec/x86/h264dsp_init.c
index 08eb7ead44..c606aac9b3 100644
--- a/libavcodec/x86/h264dsp_init.c
+++ b/libavcodec/x86/h264dsp_init.c
@@ -229,7 +229,7 @@ av_cold void ff_h264dsp_init_x86(H264DSPContext *c, const int bit_depth,
                                  const int chroma_format_idc)
 {
 #if HAVE_X86ASM
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_MMXEXT(cpu_flags) && chroma_format_idc <= 1)
         c->h264_loop_filter_strength = ff_h264_loop_filter_strength_mmxext;
diff --git a/libavcodec/x86/hevcdsp_init.c b/libavcodec/x86/hevcdsp_init.c
index 8a3fa2744b..abbcb3a132 100644
--- a/libavcodec/x86/hevcdsp_init.c
+++ b/libavcodec/x86/hevcdsp_init.c
@@ -708,7 +708,7 @@ SAO_EDGE_FILTER_FUNCS(12, avx2)
 
 void ff_hevc_dsp_init_x86(HEVCDSPContext *c, const int bit_depth)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (bit_depth == 8) {
         if (EXTERNAL_MMXEXT(cpu_flags)) {
diff --git a/libavcodec/x86/hpeldsp_init.c b/libavcodec/x86/hpeldsp_init.c
index d89928cec6..7128055b57 100644
--- a/libavcodec/x86/hpeldsp_init.c
+++ b/libavcodec/x86/hpeldsp_init.c
@@ -291,7 +291,7 @@ static void hpeldsp_init_ssse3(HpelDSPContext *c, int flags)
 
 av_cold void ff_hpeldsp_init_x86(HpelDSPContext *c, int flags)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (INLINE_MMX(cpu_flags))
         hpeldsp_init_mmx(c, flags);
diff --git a/libavcodec/x86/huffyuvdsp_init.c b/libavcodec/x86/huffyuvdsp_init.c
index eb10de383d..44d2061bed 100644
--- a/libavcodec/x86/huffyuvdsp_init.c
+++ b/libavcodec/x86/huffyuvdsp_init.c
@@ -38,7 +38,7 @@ void ff_add_hfyu_median_pred_int16_mmxext(uint16_t *dst, const uint16_t *top, co
 
 av_cold void ff_huffyuvdsp_init_x86(HuffYUVDSPContext *c, enum AVPixelFormat pix_fmt)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
     const AVPixFmtDescriptor *pix_desc = av_pix_fmt_desc_get(pix_fmt);
 
     if (ARCH_X86_32 && EXTERNAL_MMX(cpu_flags)) {
diff --git a/libavcodec/x86/huffyuvencdsp_init.c b/libavcodec/x86/huffyuvencdsp_init.c
index 6c6e068cf8..bea289b799 100644
--- a/libavcodec/x86/huffyuvencdsp_init.c
+++ b/libavcodec/x86/huffyuvencdsp_init.c
@@ -39,7 +39,7 @@ void ff_sub_hfyu_median_pred_int16_mmxext(uint16_t *dst, const uint16_t *src1, c
 
 av_cold void ff_huffyuvencdsp_init_x86(HuffYUVEncDSPContext *c, AVCodecContext *avctx)
 {
-    av_unused int cpu_flags = av_get_cpu_flags();
+    av_unused int cpu_flags = av_cpu_get_flags();
     const AVPixFmtDescriptor *pix_desc = av_pix_fmt_desc_get(avctx->pix_fmt);
 
     if (ARCH_X86_32 && EXTERNAL_MMX(cpu_flags)) {
diff --git a/libavcodec/x86/idctdsp_init.c b/libavcodec/x86/idctdsp_init.c
index 9103b92ce7..49c2a20308 100644
--- a/libavcodec/x86/idctdsp_init.c
+++ b/libavcodec/x86/idctdsp_init.c
@@ -61,7 +61,7 @@ av_cold int ff_init_scantable_permutation_x86(uint8_t *idct_permutation,
 av_cold void ff_idctdsp_init_x86(IDCTDSPContext *c, AVCodecContext *avctx,
                                  unsigned high_bit_depth)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_MMX(cpu_flags)) {
         c->put_signed_pixels_clamped = ff_put_signed_pixels_clamped_mmx;
diff --git a/libavcodec/x86/jpeg2000dsp_init.c b/libavcodec/x86/jpeg2000dsp_init.c
index 7310a1d0e1..2587bf24dd 100644
--- a/libavcodec/x86/jpeg2000dsp_init.c
+++ b/libavcodec/x86/jpeg2000dsp_init.c
@@ -33,7 +33,7 @@ void ff_rct_int_avx2 (void *src0, void *src1, void *src2, int csize);
 
 av_cold void ff_jpeg2000dsp_init_x86(Jpeg2000DSPContext *c)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
     if (EXTERNAL_SSE(cpu_flags)) {
         c->mct_decode[FF_DWT97] = ff_ict_float_sse;
     }
diff --git a/libavcodec/x86/lossless_audiodsp_init.c b/libavcodec/x86/lossless_audiodsp_init.c
index f74c7e4361..185abc7f4f 100644
--- a/libavcodec/x86/lossless_audiodsp_init.c
+++ b/libavcodec/x86/lossless_audiodsp_init.c
@@ -38,7 +38,7 @@ int32_t ff_scalarproduct_and_madd_int32_sse4(int16_t *v1, const int32_t *v2,
 av_cold void ff_llauddsp_init_x86(LLAudDSPContext *c)
 {
 #if HAVE_X86ASM
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_MMXEXT(cpu_flags))
         c->scalarproduct_and_madd_int16 = ff_scalarproduct_and_madd_int16_mmxext;
diff --git a/libavcodec/x86/lossless_videodsp_init.c b/libavcodec/x86/lossless_videodsp_init.c
index 6d71f14e7f..34aa96b971 100644
--- a/libavcodec/x86/lossless_videodsp_init.c
+++ b/libavcodec/x86/lossless_videodsp_init.c
@@ -87,7 +87,7 @@ static void add_median_pred_cmov(uint8_t *dst, const uint8_t *top,
 
 void ff_llviddsp_init_x86(LLVidDSPContext *c)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
 #if HAVE_INLINE_ASM && HAVE_7REGS && ARCH_X86_32
     if (cpu_flags & AV_CPU_FLAG_CMOV)
diff --git a/libavcodec/x86/lossless_videoencdsp_init.c b/libavcodec/x86/lossless_videoencdsp_init.c
index 40407add52..8e425c6a9c 100644
--- a/libavcodec/x86/lossless_videoencdsp_init.c
+++ b/libavcodec/x86/lossless_videoencdsp_init.c
@@ -85,7 +85,7 @@ static void sub_median_pred_mmxext(uint8_t *dst, const uint8_t *src1,
 
 av_cold void ff_llvidencdsp_init_x86(LLVidEncDSPContext *c)
 {
-    av_unused int cpu_flags = av_get_cpu_flags();
+    av_unused int cpu_flags = av_cpu_get_flags();
 
     if (ARCH_X86_32 && EXTERNAL_MMX(cpu_flags)) {
         c->diff_bytes = ff_diff_bytes_mmx;
diff --git a/libavcodec/x86/lpc.c b/libavcodec/x86/lpc.c
index 6c72e21bac..ff0bf062f8 100644
--- a/libavcodec/x86/lpc.c
+++ b/libavcodec/x86/lpc.c
@@ -152,7 +152,7 @@ static void lpc_compute_autocorr_sse2(const double *data, int len, int lag,
 av_cold void ff_lpc_init_x86(LPCContext *c)
 {
 #if HAVE_SSE2_INLINE
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (INLINE_SSE2(cpu_flags) || INLINE_SSE2_SLOW(cpu_flags)) {
         c->lpc_apply_welch_window = lpc_apply_welch_window_sse2;
diff --git a/libavcodec/x86/mdct15_init.c b/libavcodec/x86/mdct15_init.c
index 641bfd043f..8782b02d6f 100644
--- a/libavcodec/x86/mdct15_init.c
+++ b/libavcodec/x86/mdct15_init.c
@@ -82,7 +82,7 @@ static void perm_twiddles(MDCT15Context *s)
 av_cold void ff_mdct15_init_x86(MDCT15Context *s)
 {
     int adjust_twiddles = 0;
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_SSE3(cpu_flags))
         s->postreindex = ff_mdct15_postreindex_sse3;
diff --git a/libavcodec/x86/me_cmp_init.c b/libavcodec/x86/me_cmp_init.c
index 701eb1ab25..8bcf193d0f 100644
--- a/libavcodec/x86/me_cmp_init.c
+++ b/libavcodec/x86/me_cmp_init.c
@@ -556,7 +556,7 @@ PIX_SAD(mmx)
 
 av_cold void ff_me_cmp_init_x86(MECmpContext *c, AVCodecContext *avctx)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
 #if HAVE_INLINE_ASM
     if (INLINE_MMX(cpu_flags)) {
diff --git a/libavcodec/x86/mlpdsp_init.c b/libavcodec/x86/mlpdsp_init.c
index cb90ca24f0..e1d1834b3e 100644
--- a/libavcodec/x86/mlpdsp_init.c
+++ b/libavcodec/x86/mlpdsp_init.c
@@ -192,7 +192,7 @@ static void mlp_filter_channel_x86(int32_t *state, const int32_t *coeff,
 
 av_cold void ff_mlpdsp_init_x86(MLPDSPContext *c)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 #if HAVE_7REGS && HAVE_INLINE_ASM && HAVE_INLINE_ASM_NONLOCAL_LABELS
     if (INLINE_MMX(cpu_flags))
         c->mlp_filter_channel = mlp_filter_channel_x86;
diff --git a/libavcodec/x86/mpegaudiodsp.c b/libavcodec/x86/mpegaudiodsp.c
index 50692f29ce..7e7addd8c1 100644
--- a/libavcodec/x86/mpegaudiodsp.c
+++ b/libavcodec/x86/mpegaudiodsp.c
@@ -259,7 +259,7 @@ av_cold void ff_mpadsp_init_x86_tabs(void)
 
 av_cold void ff_mpadsp_init_x86(MPADSPContext *s)
 {
-    av_unused int cpu_flags = av_get_cpu_flags();
+    av_unused int cpu_flags = av_cpu_get_flags();
 
 #if HAVE_6REGS && HAVE_SSE_INLINE
     if (INLINE_SSE(cpu_flags)) {
diff --git a/libavcodec/x86/mpegvideo.c b/libavcodec/x86/mpegvideo.c
index 73967cafda..50e51b9936 100644
--- a/libavcodec/x86/mpegvideo.c
+++ b/libavcodec/x86/mpegvideo.c
@@ -454,7 +454,7 @@ __asm__ volatile(
 av_cold void ff_mpv_common_init_x86(MpegEncContext *s)
 {
 #if HAVE_MMX_INLINE
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (INLINE_MMX(cpu_flags)) {
         s->dct_unquantize_h263_intra = dct_unquantize_h263_intra_mmx;
diff --git a/libavcodec/x86/mpegvideodsp.c b/libavcodec/x86/mpegvideodsp.c
index 6009b64e07..dfb4198b79 100644
--- a/libavcodec/x86/mpegvideodsp.c
+++ b/libavcodec/x86/mpegvideodsp.c
@@ -153,7 +153,7 @@ static void gmc_mmx(uint8_t *dst, uint8_t *src,
 av_cold void ff_mpegvideodsp_init_x86(MpegVideoDSPContext *c)
 {
 #if HAVE_INLINE_ASM
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (INLINE_MMX(cpu_flags))
         c->gmc = gmc_mmx;
diff --git a/libavcodec/x86/mpegvideoenc.c b/libavcodec/x86/mpegvideoenc.c
index 4bad6a87ef..db31a4205e 100644
--- a/libavcodec/x86/mpegvideoenc.c
+++ b/libavcodec/x86/mpegvideoenc.c
@@ -217,7 +217,7 @@ av_cold void ff_dct_encode_init_x86(MpegEncContext *s)
 
     if (dct_algo == FF_DCT_AUTO || dct_algo == FF_DCT_MMX) {
 #if HAVE_MMX_INLINE
-        int cpu_flags = av_get_cpu_flags();
+        int cpu_flags = av_cpu_get_flags();
         if (INLINE_MMX(cpu_flags)) {
 #if HAVE_6REGS
             s->dct_quantize = dct_quantize_mmx;
diff --git a/libavcodec/x86/mpegvideoencdsp_init.c b/libavcodec/x86/mpegvideoencdsp_init.c
index 532836cec9..e32be95c35 100644
--- a/libavcodec/x86/mpegvideoencdsp_init.c
+++ b/libavcodec/x86/mpegvideoencdsp_init.c
@@ -217,7 +217,7 @@ static void draw_edges_mmx(uint8_t *buf, int wrap, int width, int height,
 av_cold void ff_mpegvideoencdsp_init_x86(MpegvideoEncDSPContext *c,
                                          AVCodecContext *avctx)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
 #if ARCH_X86_32
     if (EXTERNAL_MMX(cpu_flags)) {
diff --git a/libavcodec/x86/opusdsp_init.c b/libavcodec/x86/opusdsp_init.c
index 582fbb4f0c..7a9bf02635 100644
--- a/libavcodec/x86/opusdsp_init.c
+++ b/libavcodec/x86/opusdsp_init.c
@@ -27,7 +27,7 @@ float ff_opus_deemphasis_fma3(float *out, float *in, float coeff, int len);
 
 av_cold void ff_opus_dsp_init_x86(OpusDSP *ctx)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_FMA3(cpu_flags)) {
         ctx->postfilter = ff_opus_postfilter_fma3;
diff --git a/libavcodec/x86/pixblockdsp_init.c b/libavcodec/x86/pixblockdsp_init.c
index 3a5eb6959c..42fc8a1710 100644
--- a/libavcodec/x86/pixblockdsp_init.c
+++ b/libavcodec/x86/pixblockdsp_init.c
@@ -34,7 +34,7 @@ av_cold void ff_pixblockdsp_init_x86(PixblockDSPContext *c,
                                      AVCodecContext *avctx,
                                      unsigned high_bit_depth)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_MMX(cpu_flags)) {
         if (!high_bit_depth) {
diff --git a/libavcodec/x86/pngdsp_init.c b/libavcodec/x86/pngdsp_init.c
index 7dca62c675..ee73afe4a3 100644
--- a/libavcodec/x86/pngdsp_init.c
+++ b/libavcodec/x86/pngdsp_init.c
@@ -35,7 +35,7 @@ void ff_add_bytes_l2_sse2(uint8_t *dst, uint8_t *src1,
 
 av_cold void ff_pngdsp_init_x86(PNGDSPContext *dsp)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
 #if ARCH_X86_32
     if (EXTERNAL_MMX(cpu_flags))
diff --git a/libavcodec/x86/proresdsp_init.c b/libavcodec/x86/proresdsp_init.c
index bde79ab8c0..77a0d25e47 100644
--- a/libavcodec/x86/proresdsp_init.c
+++ b/libavcodec/x86/proresdsp_init.c
@@ -33,7 +33,7 @@ void ff_prores_idct_put_10_avx (uint16_t *dst, ptrdiff_t linesize,
 av_cold void ff_proresdsp_init_x86(ProresDSPContext *dsp, AVCodecContext *avctx)
 {
 #if ARCH_X86_64
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (avctx->bits_per_raw_sample == 10){
         if (EXTERNAL_SSE2(cpu_flags)) {
diff --git a/libavcodec/x86/qpeldsp_init.c b/libavcodec/x86/qpeldsp_init.c
index 3b05e156cc..e06ab7c73e 100644
--- a/libavcodec/x86/qpeldsp_init.c
+++ b/libavcodec/x86/qpeldsp_init.c
@@ -528,7 +528,7 @@ do {                                                                         \
 
 av_cold void ff_qpeldsp_init_x86(QpelDSPContext *c)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (X86_MMXEXT(cpu_flags)) {
 #if HAVE_MMXEXT_EXTERNAL
diff --git a/libavcodec/x86/rv34dsp_init.c b/libavcodec/x86/rv34dsp_init.c
index 7310122458..6f8e27b4cc 100644
--- a/libavcodec/x86/rv34dsp_init.c
+++ b/libavcodec/x86/rv34dsp_init.c
@@ -33,7 +33,7 @@ void ff_rv34_idct_add_mmxext(uint8_t *dst, ptrdiff_t stride, int16_t *block);
 
 av_cold void ff_rv34dsp_init_x86(RV34DSPContext* c)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (ARCH_X86_32 && EXTERNAL_MMX(cpu_flags))
         c->rv34_idct_dc_add = ff_rv34_idct_dc_add_mmx;
diff --git a/libavcodec/x86/rv40dsp_init.c b/libavcodec/x86/rv40dsp_init.c
index 79a617ffbe..435cb50b60 100644
--- a/libavcodec/x86/rv40dsp_init.c
+++ b/libavcodec/x86/rv40dsp_init.c
@@ -215,7 +215,7 @@ DEFINE_FN(avg, 16, mmx)
 
 av_cold void ff_rv40dsp_init_x86(RV34DSPContext *c)
 {
-    av_unused int cpu_flags = av_get_cpu_flags();
+    av_unused int cpu_flags = av_cpu_get_flags();
 
 #if HAVE_MMX_INLINE
     if (INLINE_MMX(cpu_flags)) {
diff --git a/libavcodec/x86/sbcdsp_init.c b/libavcodec/x86/sbcdsp_init.c
index 7416a86ac6..10d5adf99b 100644
--- a/libavcodec/x86/sbcdsp_init.c
+++ b/libavcodec/x86/sbcdsp_init.c
@@ -42,7 +42,7 @@ void ff_sbc_calc_scalefactors_mmx(int32_t sb_sample_f[16][2][8],
 
 av_cold void ff_sbcdsp_init_x86(SBCDSPContext *s)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_MMX(cpu_flags)) {
         s->sbc_analyze_4 = ff_sbc_analyze_4_mmx;
diff --git a/libavcodec/x86/sbrdsp_init.c b/libavcodec/x86/sbrdsp_init.c
index 6911a1a515..85ef998400 100644
--- a/libavcodec/x86/sbrdsp_init.c
+++ b/libavcodec/x86/sbrdsp_init.c
@@ -58,7 +58,7 @@ void ff_sbr_autocorrelate_sse3(const float x[40][2], float phi[3][2][2]);
 
 av_cold void ff_sbrdsp_init_x86(SBRDSPContext *s)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_SSE(cpu_flags)) {
         s->neg_odd_64 = ff_sbr_neg_odd_64_sse;
diff --git a/libavcodec/x86/snowdsp.c b/libavcodec/x86/snowdsp.c
index 84bc74f915..11d11a15c9 100644
--- a/libavcodec/x86/snowdsp.c
+++ b/libavcodec/x86/snowdsp.c
@@ -881,7 +881,7 @@ static void ff_snow_inner_add_yblock_mmx(const uint8_t *obmc, const int obmc_str
 av_cold void ff_dwt_init_x86(SnowDWTContext *c)
 {
 #if HAVE_INLINE_ASM
-    int mm_flags = av_get_cpu_flags();
+    int mm_flags = av_cpu_get_flags();
 
     if (mm_flags & AV_CPU_FLAG_MMX) {
         if(mm_flags & AV_CPU_FLAG_SSE2 & 0){
diff --git a/libavcodec/x86/svq1enc_init.c b/libavcodec/x86/svq1enc_init.c
index 40b4b0e183..de00cdf6b2 100644
--- a/libavcodec/x86/svq1enc_init.c
+++ b/libavcodec/x86/svq1enc_init.c
@@ -31,7 +31,7 @@ int ff_ssd_int8_vs_int16_sse2(const int8_t *pix1, const int16_t *pix2,
 
 av_cold void ff_svq1enc_init_x86(SVQ1EncContext *c)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_MMX(cpu_flags)) {
         c->ssd_int8_vs_int16 = ff_ssd_int8_vs_int16_mmx;
diff --git a/libavcodec/x86/synth_filter_init.c b/libavcodec/x86/synth_filter_init.c
index 35e2b47a3e..51a810861a 100644
--- a/libavcodec/x86/synth_filter_init.c
+++ b/libavcodec/x86/synth_filter_init.c
@@ -54,7 +54,7 @@ SYNTH_FILTER_FUNC(fma3)
 av_cold void ff_synth_filter_init_x86(SynthFilterContext *s)
 {
 #if HAVE_X86ASM
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
 #if ARCH_X86_32
     if (EXTERNAL_SSE(cpu_flags)) {
diff --git a/libavcodec/x86/takdsp_init.c b/libavcodec/x86/takdsp_init.c
index b2e6e639ee..d4ce39fa8a 100644
--- a/libavcodec/x86/takdsp_init.c
+++ b/libavcodec/x86/takdsp_init.c
@@ -31,7 +31,7 @@ void ff_tak_decorrelate_sf_sse4(int32_t *p1, int32_t *p2, int length, int dshift
 av_cold void ff_takdsp_init_x86(TAKDSPContext *c)
 {
 #if HAVE_X86ASM
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_SSE2(cpu_flags)) {
         c->decorrelate_ls = ff_tak_decorrelate_ls_sse2;
diff --git a/libavcodec/x86/ttadsp_init.c b/libavcodec/x86/ttadsp_init.c
index f2954e5687..6f6a7dd666 100644
--- a/libavcodec/x86/ttadsp_init.c
+++ b/libavcodec/x86/ttadsp_init.c
@@ -33,7 +33,7 @@ void ff_tta_filter_process_sse4(int32_t *qm, int32_t *dx, int32_t *dl,
 av_cold void ff_ttadsp_init_x86(TTADSPContext *c)
 {
 #if HAVE_X86ASM
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_SSSE3(cpu_flags))
         c->filter_process = ff_tta_filter_process_ssse3;
diff --git a/libavcodec/x86/ttaencdsp_init.c b/libavcodec/x86/ttaencdsp_init.c
index b470142c50..9b63a25305 100644
--- a/libavcodec/x86/ttaencdsp_init.c
+++ b/libavcodec/x86/ttaencdsp_init.c
@@ -33,7 +33,7 @@ void ff_ttaenc_filter_process_sse4(int32_t *qm, int32_t *dx, int32_t *dl,
 av_cold void ff_ttaencdsp_init_x86(TTAEncDSPContext *c)
 {
 #if HAVE_X86ASM
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_SSSE3(cpu_flags))
         c->filter_process = ff_ttaenc_filter_process_ssse3;
diff --git a/libavcodec/x86/utvideodsp_init.c b/libavcodec/x86/utvideodsp_init.c
index 2b436c6c5c..4804b28f3f 100644
--- a/libavcodec/x86/utvideodsp_init.c
+++ b/libavcodec/x86/utvideodsp_init.c
@@ -41,7 +41,7 @@ void ff_restore_rgb_planes10_avx2(uint16_t *src_r, uint16_t *src_g, uint16_t *sr
 
 av_cold void ff_utvideodsp_init_x86(UTVideoDSPContext *c)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_SSE2(cpu_flags)) {
         c->restore_rgb_planes   = ff_restore_rgb_planes_sse2;
diff --git a/libavcodec/x86/v210-init.c b/libavcodec/x86/v210-init.c
index 5db1fef98c..e5982a177b 100644
--- a/libavcodec/x86/v210-init.c
+++ b/libavcodec/x86/v210-init.c
@@ -31,7 +31,7 @@ extern void ff_v210_planar_unpack_aligned_avx2(const uint32_t *src, uint16_t *y,
 av_cold void ff_v210_x86_init(V210DecContext *s)
 {
 #if HAVE_X86ASM
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (s->aligned_input) {
         if (cpu_flags & AV_CPU_FLAG_SSSE3)
diff --git a/libavcodec/x86/v210enc_init.c b/libavcodec/x86/v210enc_init.c
index 13a351dd1d..b6718e237a 100644
--- a/libavcodec/x86/v210enc_init.c
+++ b/libavcodec/x86/v210enc_init.c
@@ -36,7 +36,7 @@ void ff_v210_planar_pack_10_avx2(const uint16_t *y, const uint16_t *u,
 
 av_cold void ff_v210enc_init_x86(V210EncContext *s)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_SSSE3(cpu_flags)) {
         s->pack_line_8 = ff_v210_planar_pack_8_ssse3;
diff --git a/libavcodec/x86/vc1dsp_init.c b/libavcodec/x86/vc1dsp_init.c
index 8e0c284cc0..07ced0cc70 100644
--- a/libavcodec/x86/vc1dsp_init.c
+++ b/libavcodec/x86/vc1dsp_init.c
@@ -104,7 +104,7 @@ void ff_vc1_inv_trans_8x8_dc_mmxext(uint8_t *dest, ptrdiff_t linesize,
 
 av_cold void ff_vc1dsp_init_x86(VC1DSPContext *dsp)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (HAVE_6REGS && INLINE_MMX(cpu_flags))
         if (EXTERNAL_MMX(cpu_flags))
diff --git a/libavcodec/x86/videodsp_init.c b/libavcodec/x86/videodsp_init.c
index eeebb41547..104070c283 100644
--- a/libavcodec/x86/videodsp_init.c
+++ b/libavcodec/x86/videodsp_init.c
@@ -279,7 +279,7 @@ void ff_prefetch_3dnow(uint8_t *buf, ptrdiff_t stride, int h);
 av_cold void ff_videodsp_init_x86(VideoDSPContext *ctx, int bpc)
 {
 #if HAVE_X86ASM
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
 #if ARCH_X86_32
     if (EXTERNAL_MMX(cpu_flags) && bpc <= 8) {
diff --git a/libavcodec/x86/vorbisdsp_init.c b/libavcodec/x86/vorbisdsp_init.c
index bc1cc43a18..2f6e429c3c 100644
--- a/libavcodec/x86/vorbisdsp_init.c
+++ b/libavcodec/x86/vorbisdsp_init.c
@@ -31,7 +31,7 @@ void ff_vorbis_inverse_coupling_sse(float *mag, float *ang,
 
 av_cold void ff_vorbisdsp_init_x86(VorbisDSPContext *dsp)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
 #if ARCH_X86_32
     if (EXTERNAL_AMD3DNOW(cpu_flags))
diff --git a/libavcodec/x86/vp3dsp_init.c b/libavcodec/x86/vp3dsp_init.c
index ba47e1c6cd..cff7a6594a 100644
--- a/libavcodec/x86/vp3dsp_init.c
+++ b/libavcodec/x86/vp3dsp_init.c
@@ -45,7 +45,7 @@ void ff_put_vp_no_rnd_pixels8_l2_mmx(uint8_t *dst, const uint8_t *a,
 
 av_cold void ff_vp3dsp_init_x86(VP3DSPContext *c, int flags)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_MMX(cpu_flags)) {
         c->put_no_rnd_pixels_l2 = ff_put_vp_no_rnd_pixels8_l2_mmx;
diff --git a/libavcodec/x86/vp6dsp_init.c b/libavcodec/x86/vp6dsp_init.c
index ce498931d0..5915531ddc 100644
--- a/libavcodec/x86/vp6dsp_init.c
+++ b/libavcodec/x86/vp6dsp_init.c
@@ -32,7 +32,7 @@ void ff_vp6_filter_diag4_sse2(uint8_t *dst, uint8_t *src, ptrdiff_t stride,
 
 av_cold void ff_vp6dsp_init_x86(VP56DSPContext *c)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
 #if ARCH_X86_32
     if (EXTERNAL_MMX(cpu_flags)) {
diff --git a/libavcodec/x86/vp8dsp_init.c b/libavcodec/x86/vp8dsp_init.c
index dffa7a2418..b2cb3aa6a2 100644
--- a/libavcodec/x86/vp8dsp_init.c
+++ b/libavcodec/x86/vp8dsp_init.c
@@ -320,7 +320,7 @@ DECLARE_LOOP_FILTER(sse4)
 av_cold void ff_vp78dsp_init_x86(VP8DSPContext *c)
 {
 #if HAVE_X86ASM
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_MMX(cpu_flags)) {
 #if ARCH_X86_32
@@ -370,7 +370,7 @@ av_cold void ff_vp78dsp_init_x86(VP8DSPContext *c)
 av_cold void ff_vp8dsp_init_x86(VP8DSPContext *c)
 {
 #if HAVE_X86ASM
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_MMX(cpu_flags)) {
         c->vp8_idct_dc_add4uv = ff_vp8_idct_dc_add4uv_mmx;
diff --git a/libavcodec/x86/vp9dsp_init.c b/libavcodec/x86/vp9dsp_init.c
index 837cce8508..9ebf1e56f4 100644
--- a/libavcodec/x86/vp9dsp_init.c
+++ b/libavcodec/x86/vp9dsp_init.c
@@ -227,7 +227,7 @@ av_cold void ff_vp9dsp_init_x86(VP9DSPContext *dsp, int bpp, int bitexact)
         return;
     }
 
-    cpu_flags = av_get_cpu_flags();
+    cpu_flags = av_cpu_get_flags();
 
 #define init_lpf(opt) do { \
     dsp->loop_filter_16[0] = ff_vp9_loop_filter_h_16_16_##opt; \
diff --git a/libavcodec/x86/vp9dsp_init_16bpp.c b/libavcodec/x86/vp9dsp_init_16bpp.c
index 60d10a12a3..e35981d641 100644
--- a/libavcodec/x86/vp9dsp_init_16bpp.c
+++ b/libavcodec/x86/vp9dsp_init_16bpp.c
@@ -72,7 +72,7 @@ decl_ipred_dir_funcs(hd);
 av_cold void ff_vp9dsp_init_16bpp_x86(VP9DSPContext *dsp)
 {
 #if HAVE_X86ASM
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_MMX(cpu_flags)) {
         init_fpel_func(4, 0,   8, put, , mmx);
diff --git a/libavcodec/x86/vp9dsp_init_16bpp_template.c b/libavcodec/x86/vp9dsp_init_16bpp_template.c
index b56afc7f50..9a02990109 100644
--- a/libavcodec/x86/vp9dsp_init_16bpp_template.c
+++ b/libavcodec/x86/vp9dsp_init_16bpp_template.c
@@ -142,7 +142,7 @@ decl_itxfm_func(idct,  idct, 32, BPC, sse2);
 av_cold void INIT_FUNC(VP9DSPContext *dsp, int bitexact)
 {
 #if HAVE_X86ASM
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
 #define init_lpf_8_func(idx1, idx2, dir, wd, bpp, opt) \
     dsp->loop_filter_8[idx1][idx2] = ff_vp9_loop_filter_##dir##_##wd##_##bpp##_##opt
diff --git a/libavcodec/x86/xvididct_init.c b/libavcodec/x86/xvididct_init.c
index a91b416b74..362ad8ccfa 100644
--- a/libavcodec/x86/xvididct_init.c
+++ b/libavcodec/x86/xvididct_init.c
@@ -56,7 +56,7 @@ av_cold void ff_xvid_idct_init_x86(IDCTDSPContext *c, AVCodecContext *avctx,
                                    unsigned high_bit_depth)
 {
 #if HAVE_X86ASM
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (high_bit_depth ||
         !(avctx->idct_algo == FF_IDCT_AUTO ||
diff --git a/libavfilter/x86/af_afir_init.c b/libavfilter/x86/af_afir_init.c
index c37212c381..b8b55052f9 100644
--- a/libavfilter/x86/af_afir_init.c
+++ b/libavfilter/x86/af_afir_init.c
@@ -29,7 +29,7 @@ void ff_fcmul_add_avx(float *sum, const float *t, const float *c,
 
 av_cold void ff_afir_init_x86(AudioFIRDSPContext *s)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_SSE3(cpu_flags)) {
         s->fcmul_add = ff_fcmul_add_sse3;
diff --git a/libavfilter/x86/af_anlmdn_init.c b/libavfilter/x86/af_anlmdn_init.c
index 30eff6f644..6b9fef9b8f 100644
--- a/libavfilter/x86/af_anlmdn_init.c
+++ b/libavfilter/x86/af_anlmdn_init.c
@@ -27,7 +27,7 @@ float ff_compute_distance_ssd_sse(const float *f1, const float *f2,
 
 av_cold void ff_anlmdn_init_x86(AudioNLMDNDSPContext *s)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_SSE(cpu_flags)) {
         s->compute_distance_ssd = ff_compute_distance_ssd_sse;
diff --git a/libavfilter/x86/af_volume_init.c b/libavfilter/x86/af_volume_init.c
index 88f5a9679a..ef0c3dc64f 100644
--- a/libavfilter/x86/af_volume_init.c
+++ b/libavfilter/x86/af_volume_init.c
@@ -35,7 +35,7 @@ void ff_scale_samples_s32_avx(uint8_t *dst, const uint8_t *src, int len,
 
 av_cold void ff_volume_init_x86(VolumeContext *vol)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
     enum AVSampleFormat sample_fmt = av_get_packed_sample_fmt(vol->sample_fmt);
 
     if (sample_fmt == AV_SAMPLE_FMT_S16) {
diff --git a/libavfilter/x86/avf_showcqt_init.c b/libavfilter/x86/avf_showcqt_init.c
index 0cc164c352..85154f062f 100644
--- a/libavfilter/x86/avf_showcqt_init.c
+++ b/libavfilter/x86/avf_showcqt_init.c
@@ -46,7 +46,7 @@ static void permute_coeffs_01452367(float *v, int len)
 
 av_cold void ff_showcqt_init_x86(ShowCQTContext *s)
 {
-    int cpuflags = av_get_cpu_flags();
+    int cpuflags = av_cpu_get_flags();
 
 #define SELECT_CQT_CALC(type, TYPE, align, perm) \
 if (EXTERNAL_##TYPE(cpuflags)) { \
diff --git a/libavfilter/x86/colorspacedsp_init.c b/libavfilter/x86/colorspacedsp_init.c
index b5006ac295..2a1ce79a52 100644
--- a/libavfilter/x86/colorspacedsp_init.c
+++ b/libavfilter/x86/colorspacedsp_init.c
@@ -78,7 +78,7 @@ void ff_multiply3x3_sse2(int16_t *data[3], ptrdiff_t stride, int w, int h,
 
 void ff_colorspacedsp_x86_init(ColorSpaceDSPContext *dsp)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (ARCH_X86_64 && EXTERNAL_SSE2(cpu_flags)) {
 #define assign_yuv2yuv_fns(ss) \
diff --git a/libavfilter/x86/scene_sad_init.c b/libavfilter/x86/scene_sad_init.c
index 2c3729ceee..45f894c772 100644
--- a/libavfilter/x86/scene_sad_init.c
+++ b/libavfilter/x86/scene_sad_init.c
@@ -46,7 +46,7 @@ SCENE_SAD_FUNC(scene_sad_avx2, ff_scene_sad_avx2, 32)
 ff_scene_sad_fn ff_scene_sad_get_fn_x86(int depth)
 {
 #if HAVE_X86ASM
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
     if (depth == 8) {
 #if HAVE_AVX2_EXTERNAL
         if (EXTERNAL_AVX2_FAST(cpu_flags))
diff --git a/libavfilter/x86/vf_atadenoise_init.c b/libavfilter/x86/vf_atadenoise_init.c
index 3f87f3c445..7773daf7ff 100644
--- a/libavfilter/x86/vf_atadenoise_init.c
+++ b/libavfilter/x86/vf_atadenoise_init.c
@@ -37,7 +37,7 @@ void ff_atadenoise_filter_row8_serial_sse4(const uint8_t *src, uint8_t *dst,
 
 av_cold void ff_atadenoise_init_x86(ATADenoiseDSPContext *dsp, int depth, int algorithm, const float *sigma)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     for (int p = 0; p < 4; p++) {
         if (ARCH_X86_64 && EXTERNAL_SSE4(cpu_flags) && depth <= 8 && algorithm == PARALLEL && sigma[p] == INT16_MAX) {
diff --git a/libavfilter/x86/vf_blend_init.c b/libavfilter/x86/vf_blend_init.c
index 84bc55cc87..c98ad3b031 100644
--- a/libavfilter/x86/vf_blend_init.c
+++ b/libavfilter/x86/vf_blend_init.c
@@ -102,7 +102,7 @@ BLEND_FUNC(xor_16, avx2)
 
 av_cold void ff_blend_init_x86(FilterParams *param, int depth)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (depth == 8) {
         if (EXTERNAL_SSE2(cpu_flags) && param->opacity == 1) {
diff --git a/libavfilter/x86/vf_bwdif_init.c b/libavfilter/x86/vf_bwdif_init.c
index b1e70b3bc6..5f29c1416e 100644
--- a/libavfilter/x86/vf_bwdif_init.c
+++ b/libavfilter/x86/vf_bwdif_init.c
@@ -54,7 +54,7 @@ void ff_bwdif_filter_line_12bit_ssse3(void *dst, void *prev, void *cur, void *ne
 av_cold void ff_bwdif_init_x86(BWDIFContext *bwdif)
 {
     YADIFContext *yadif = &bwdif->yadif;
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
     int bit_depth = (!yadif->csp) ? 8 : yadif->csp->comp[0].depth;
 
     if (bit_depth <= 8) {
diff --git a/libavfilter/x86/vf_convolution_init.c b/libavfilter/x86/vf_convolution_init.c
index b78a47d02b..72bd7ba16b 100644
--- a/libavfilter/x86/vf_convolution_init.c
+++ b/libavfilter/x86/vf_convolution_init.c
@@ -33,7 +33,7 @@ av_cold void ff_convolution_init_x86(ConvolutionContext *s)
 {
 #if ARCH_X86_64
     int i;
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
     for (i = 0; i < 4; i++) {
         if (s->mode[i] == MATRIX_SQUARE) {
             if (s->matrix_length[i] == 9 && s->depth == 8) {
diff --git a/libavfilter/x86/vf_framerate_init.c b/libavfilter/x86/vf_framerate_init.c
index 9d40faf0a4..f7e01de96e 100644
--- a/libavfilter/x86/vf_framerate_init.c
+++ b/libavfilter/x86/vf_framerate_init.c
@@ -27,7 +27,7 @@ void ff_blend_frames16_avx2(BLEND_FUNC_PARAMS);
 
 void ff_framerate_init_x86(FrameRateContext *s)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
     if (s->bitdepth == 8) {
         if (EXTERNAL_AVX2_FAST(cpu_flags))
             s->blend = ff_blend_frames_avx2;
diff --git a/libavfilter/x86/vf_gblur_init.c b/libavfilter/x86/vf_gblur_init.c
index d80fb46fe4..6d30675185 100644
--- a/libavfilter/x86/vf_gblur_init.c
+++ b/libavfilter/x86/vf_gblur_init.c
@@ -32,7 +32,7 @@ void ff_postscale_slice_avx2(float *ptr, int length, float postscale, float min,
 
 av_cold void ff_gblur_init_x86(GBlurContext *s)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_SSE(cpu_flags)) {
         s->postscale_slice = ff_postscale_slice_sse;
diff --git a/libavfilter/x86/vf_gradfun_init.c b/libavfilter/x86/vf_gradfun_init.c
index 4009711701..51d8dde1fc 100644
--- a/libavfilter/x86/vf_gradfun_init.c
+++ b/libavfilter/x86/vf_gradfun_init.c
@@ -92,7 +92,7 @@ static void gradfun_blur_line_sse2(uint16_t *dc, uint16_t *buf, const uint16_t *
 av_cold void ff_gradfun_init_x86(GradFunContext *gf)
 {
 #if HAVE_X86ASM
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_MMXEXT(cpu_flags))
         gf->filter_line = gradfun_filter_line_mmxext;
diff --git a/libavfilter/x86/vf_hflip_init.c b/libavfilter/x86/vf_hflip_init.c
index 0ac399b0d4..abbdfffe15 100644
--- a/libavfilter/x86/vf_hflip_init.c
+++ b/libavfilter/x86/vf_hflip_init.c
@@ -30,7 +30,7 @@ void ff_hflip_short_avx2(const uint8_t *src, uint8_t *dst, int w);
 
 av_cold void ff_hflip_init_x86(FlipContext *s, int step[4], int nb_planes)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
     int i;
 
     for (i = 0; i < nb_planes; i++) {
diff --git a/libavfilter/x86/vf_idet_init.c b/libavfilter/x86/vf_idet_init.c
index ca175e2d40..d8a379a845 100644
--- a/libavfilter/x86/vf_idet_init.c
+++ b/libavfilter/x86/vf_idet_init.c
@@ -69,7 +69,7 @@ FUNC_MAIN_DECL_16bit(mmx, 4)
 av_cold void ff_idet_init_x86(IDETContext *idet, int for_16b)
 {
 #if HAVE_X86ASM
-    const int cpu_flags = av_get_cpu_flags();
+    const int cpu_flags = av_cpu_get_flags();
 
 #if ARCH_X86_32
     if (EXTERNAL_MMX(cpu_flags)) {
diff --git a/libavfilter/x86/vf_limiter_init.c b/libavfilter/x86/vf_limiter_init.c
index 07c733dc21..760b3dd76f 100644
--- a/libavfilter/x86/vf_limiter_init.c
+++ b/libavfilter/x86/vf_limiter_init.c
@@ -29,7 +29,7 @@ void ff_limiter_16bit_sse4(const uint8_t *src, uint8_t *dst,
 
 void ff_limiter_init_x86(LimiterDSPContext *dsp, int bpp)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_SSE2(cpu_flags)) {
         if (bpp <= 8) {
diff --git a/libavfilter/x86/vf_maskedclamp_init.c b/libavfilter/x86/vf_maskedclamp_init.c
index 53153f80ea..c9ddb5c293 100644
--- a/libavfilter/x86/vf_maskedclamp_init.c
+++ b/libavfilter/x86/vf_maskedclamp_init.c
@@ -35,7 +35,7 @@ void ff_maskedclamp16_sse4(const uint8_t *bsrc, uint8_t *dst,
 
 av_cold void ff_maskedclamp_init_x86(MaskedClampDSPContext *dsp, int depth)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_SSE2(cpu_flags) && depth <= 8) {
         dsp->maskedclamp = ff_maskedclamp8_sse2;
diff --git a/libavfilter/x86/vf_maskedmerge_init.c b/libavfilter/x86/vf_maskedmerge_init.c
index 73ab888083..758030ff4b 100644
--- a/libavfilter/x86/vf_maskedmerge_init.c
+++ b/libavfilter/x86/vf_maskedmerge_init.c
@@ -32,7 +32,7 @@ void ff_maskedmerge8_sse2(const uint8_t *bsrc, const uint8_t *osrc,
 
 av_cold void ff_maskedmerge_init_x86(MaskedMergeContext *s)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_SSE2(cpu_flags) && s->depth == 8) {
         s->maskedmerge = ff_maskedmerge8_sse2;
diff --git a/libavfilter/x86/vf_noise.c b/libavfilter/x86/vf_noise.c
index f7a4d00336..0124122bba 100644
--- a/libavfilter/x86/vf_noise.c
+++ b/libavfilter/x86/vf_noise.c
@@ -129,7 +129,7 @@ static void line_noise_mmxext(uint8_t *dst, const uint8_t *src,
 av_cold void ff_noise_init_x86(NoiseContext *n)
 {
 #if HAVE_INLINE_ASM
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (INLINE_MMX(cpu_flags)) {
         n->line_noise     = line_noise_mmx;
diff --git a/libavfilter/x86/vf_overlay_init.c b/libavfilter/x86/vf_overlay_init.c
index d4218b18f6..facac818fb 100644
--- a/libavfilter/x86/vf_overlay_init.c
+++ b/libavfilter/x86/vf_overlay_init.c
@@ -35,7 +35,7 @@ int ff_overlay_row_22_sse4(uint8_t *d, uint8_t *da, uint8_t *s, uint8_t *a,
 av_cold void ff_overlay_init_x86(OverlayContext *s, int format, int pix_format,
                                  int alpha_format, int main_has_alpha)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_SSE4(cpu_flags) &&
         (format == OVERLAY_FORMAT_YUV444 ||
diff --git a/libavfilter/x86/vf_psnr_init.c b/libavfilter/x86/vf_psnr_init.c
index c387812204..057e6de034 100644
--- a/libavfilter/x86/vf_psnr_init.c
+++ b/libavfilter/x86/vf_psnr_init.c
@@ -27,7 +27,7 @@ uint64_t ff_sse_line_16bit_sse2(const uint8_t *buf, const uint8_t *ref, int w);
 
 void ff_psnr_init_x86(PSNRDSPContext *dsp, int bpp)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_SSE2(cpu_flags)) {
         if (bpp <= 8) {
diff --git a/libavfilter/x86/vf_ssim_init.c b/libavfilter/x86/vf_ssim_init.c
index cbaa20ef16..6d74e760d0 100644
--- a/libavfilter/x86/vf_ssim_init.c
+++ b/libavfilter/x86/vf_ssim_init.c
@@ -32,7 +32,7 @@ double ff_ssim_end_line_sse4(const int (*sum0)[4], const int (*sum1)[4], int w);
 
 void ff_ssim_init_x86(SSIMDSPContext *dsp)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (ARCH_X86_64 && EXTERNAL_SSSE3(cpu_flags))
         dsp->ssim_4x4_line = ff_ssim_4x4_line_ssse3;
diff --git a/libavfilter/x86/vf_threshold_init.c b/libavfilter/x86/vf_threshold_init.c
index 8e42296791..c2fa915046 100644
--- a/libavfilter/x86/vf_threshold_init.c
+++ b/libavfilter/x86/vf_threshold_init.c
@@ -39,7 +39,7 @@ THRESHOLD_FUNC(16, avx2)
 
 av_cold void ff_threshold_init_x86(ThresholdContext *s)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (s->depth == 8) {
         if (EXTERNAL_SSE4(cpu_flags)) {
diff --git a/libavfilter/x86/vf_transpose_init.c b/libavfilter/x86/vf_transpose_init.c
index 6bb9908725..9c4c75b598 100644
--- a/libavfilter/x86/vf_transpose_init.c
+++ b/libavfilter/x86/vf_transpose_init.c
@@ -37,7 +37,7 @@ void ff_transpose_8x8_16_sse2(uint8_t *src,
 
 av_cold void ff_transpose_init_x86(TransVtable *v, int pixstep)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_SSE2(cpu_flags) && pixstep == 1) {
         v->transpose_8x8 = ff_transpose_8x8_8_sse2;
diff --git a/libavfilter/x86/vf_v360_init.c b/libavfilter/x86/vf_v360_init.c
index 2b2b06dd40..988e176f61 100644
--- a/libavfilter/x86/vf_v360_init.c
+++ b/libavfilter/x86/vf_v360_init.c
@@ -43,7 +43,7 @@ void ff_remap2_16bit_line_avx2(uint8_t *dst, int width, const uint8_t *src, ptrd
 
 av_cold void ff_v360_init_x86(V360Context *s, int depth)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_AVX2_FAST(cpu_flags) && s->interp == NEAREST && depth <= 8)
         s->remap_line = ff_remap1_8bit_line_avx2;
diff --git a/libavfilter/x86/vf_w3fdif_init.c b/libavfilter/x86/vf_w3fdif_init.c
index d4534bb1ed..54f6231c3c 100644
--- a/libavfilter/x86/vf_w3fdif_init.c
+++ b/libavfilter/x86/vf_w3fdif_init.c
@@ -48,7 +48,7 @@ void ff_w3fdif_scale_sse2(uint8_t *out_pixel, const int32_t *work_pixel,
 
 av_cold void ff_w3fdif_init_x86(W3FDIFDSPContext *dsp, int depth)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_SSE2(cpu_flags) && depth <= 8) {
         dsp->filter_simple_low   = ff_w3fdif_simple_low_sse2;
diff --git a/libavfilter/x86/vf_yadif_init.c b/libavfilter/x86/vf_yadif_init.c
index c39bc44da6..a2c17f6634 100644
--- a/libavfilter/x86/vf_yadif_init.c
+++ b/libavfilter/x86/vf_yadif_init.c
@@ -59,7 +59,7 @@ void ff_yadif_filter_line_10bit_ssse3(void *dst, void *prev, void *cur,
 
 av_cold void ff_yadif_init_x86(YADIFContext *yadif)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
     int bit_depth = (!yadif->csp) ? 8
                                   : yadif->csp->comp[0].depth;
 
diff --git a/libavutil/cpu.c b/libavutil/cpu.c
index eae1485f36..fa8097e1cb 100644
--- a/libavutil/cpu.c
+++ b/libavutil/cpu.c
@@ -65,7 +65,7 @@ static int get_cpu_flags(void)
     return 0;
 }
 
-void av_force_cpu_flags(int arg){
+void av_cpu_force_flags(int arg){
     if (ARCH_X86 &&
            (arg & ( AV_CPU_FLAG_3DNOW    |
                     AV_CPU_FLAG_3DNOWEXT |
@@ -93,7 +93,7 @@ void av_force_cpu_flags(int arg){
     atomic_store_explicit(&cpu_flags, arg, memory_order_relaxed);
 }
 
-int av_get_cpu_flags(void)
+int av_cpu_get_flags(void)
 {
     int flags = atomic_load_explicit(&cpu_flags, memory_order_relaxed);
     if (flags == -1) {
@@ -103,7 +103,7 @@ int av_get_cpu_flags(void)
     return flags;
 }
 
-int av_parse_cpu_caps(unsigned *flags, const char *s)
+int av_cpu_parse_caps(unsigned *flags, const char *s)
 {
         static const AVOption cpuflags_opts[] = {
         { "flags"   , NULL, 0, AV_OPT_TYPE_FLAGS, { .i64 = 0 }, INT64_MIN, INT64_MAX, .unit = "flags" },
@@ -236,7 +236,7 @@ int av_cpu_count(void)
     return nb_cpus;
 }
 
-void av_force_cpu_count(int count){
+void av_cpu_force_count(int count){
     atomic_store_explicit(&cpu_count, count, memory_order_relaxed);
 }
 
diff --git a/libavutil/x86/cpu.c b/libavutil/x86/cpu.c
index bcd41a50a2..57516631d5 100644
--- a/libavutil/x86/cpu.c
+++ b/libavutil/x86/cpu.c
@@ -244,7 +244,7 @@ int ff_get_cpu_flags_x86(void)
 
 size_t ff_get_cpu_max_align_x86(void)
 {
-    int flags = av_get_cpu_flags();
+    int flags = av_cpu_get_flags();
 
     if (flags & AV_CPU_FLAG_AVX512)
         return 64;
diff --git a/libavutil/x86/fixed_dsp_init.c b/libavutil/x86/fixed_dsp_init.c
index 303a2eb922..a9588dba8b 100644
--- a/libavutil/x86/fixed_dsp_init.c
+++ b/libavutil/x86/fixed_dsp_init.c
@@ -27,7 +27,7 @@ void ff_butterflies_fixed_sse2(int *src0, int *src1, int len);
 
 av_cold void ff_fixed_dsp_init_x86(AVFixedDSPContext *fdsp)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_SSE2(cpu_flags)) {
         fdsp->butterflies_fixed = ff_butterflies_fixed_sse2;
diff --git a/libavutil/x86/float_dsp_init.c b/libavutil/x86/float_dsp_init.c
index 8826e4e2c9..8fbb676a7e 100644
--- a/libavutil/x86/float_dsp_init.c
+++ b/libavutil/x86/float_dsp_init.c
@@ -81,7 +81,7 @@ void ff_butterflies_float_sse(float *av_restrict src0, float *av_restrict src1,
 
 av_cold void ff_float_dsp_init_x86(AVFloatDSPContext *fdsp)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_AMD3DNOWEXT(cpu_flags)) {
         fdsp->vector_fmul_window = ff_vector_fmul_window_3dnowext;
diff --git a/libavutil/x86/imgutils_init.c b/libavutil/x86/imgutils_init.c
index 4ea398205e..d53765f6be 100644
--- a/libavutil/x86/imgutils_init.c
+++ b/libavutil/x86/imgutils_init.c
@@ -35,7 +35,7 @@ int ff_image_copy_plane_uc_from_x86(uint8_t       *dst, ptrdiff_t dst_linesize,
                                     const uint8_t *src, ptrdiff_t src_linesize,
                                     ptrdiff_t bytewidth, int height)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
     ptrdiff_t bw_aligned = FFALIGN(bytewidth, 64);
 
     if (EXTERNAL_SSE4(cpu_flags) &&
diff --git a/libavutil/x86/lls_init.c b/libavutil/x86/lls_init.c
index c786376915..3ead500514 100644
--- a/libavutil/x86/lls_init.c
+++ b/libavutil/x86/lls_init.c
@@ -31,7 +31,7 @@ double ff_evaluate_lls_sse2(LLSModel *m, const double *var, int order);
 
 av_cold void ff_init_lls_x86(LLSModel *m)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
     if (EXTERNAL_SSE2(cpu_flags)) {
         m->update_lls = ff_update_lls_sse2;
         if (m->indep_count >= 4)
diff --git a/libavutil/x86/pixelutils_init.c b/libavutil/x86/pixelutils_init.c
index 184a3a4a9f..78f5ad49f2 100644
--- a/libavutil/x86/pixelutils_init.c
+++ b/libavutil/x86/pixelutils_init.c
@@ -51,7 +51,7 @@ int ff_pixelutils_sad_u_32x32_avx2(const uint8_t *src1, ptrdiff_t stride1,
 
 void ff_pixelutils_sad_init_x86(av_pixelutils_sad_fn *sad, int aligned)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_MMX(cpu_flags)) {
         sad[2] = ff_pixelutils_sad_8x8_mmx;
diff --git a/libavutil/x86/tx_float_init.c b/libavutil/x86/tx_float_init.c
index 8b77a5f29f..ad5652fa3e 100644
--- a/libavutil/x86/tx_float_init.c
+++ b/libavutil/x86/tx_float_init.c
@@ -36,7 +36,7 @@ void ff_split_radix_fft_float_avx2(AVTXContext *s, void *out, void *in, ptrdiff_
 
 av_cold void ff_tx_init_float_x86(AVTXContext *s, av_tx_fn *tx)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
     int gen_revtab = 0, basis, revtab_interleave;
 
     if (s->flags & AV_TX_UNALIGNED)
diff --git a/libswresample/resample.c b/libswresample/resample.c
index df49505bf9..f4778b34cb 100644
--- a/libswresample/resample.c
+++ b/libswresample/resample.c
@@ -451,7 +451,7 @@ static int set_compensation(ResampleContext *c, int sample_delta, int compensati
 
 static int multiple_resample(ResampleContext *c, AudioData *dst, int dst_size, AudioData *src, int src_size, int *consumed){
     int i;
-    int av_unused mm_flags = av_get_cpu_flags();
+    int av_unused mm_flags = av_cpu_get_flags();
     int need_emms = c->format == AV_SAMPLE_FMT_S16P && ARCH_X86_32 &&
                     (mm_flags & (AV_CPU_FLAG_MMX2 | AV_CPU_FLAG_SSE2)) == AV_CPU_FLAG_MMX2;
     int64_t max_src_size = (INT64_MAX/2 / c->phase_count) / c->src_incr;
diff --git a/libswresample/x86/audio_convert_init.c b/libswresample/x86/audio_convert_init.c
index a7d5ab89f8..ba8cf831d0 100644
--- a/libswresample/x86/audio_convert_init.c
+++ b/libswresample/x86/audio_convert_init.c
@@ -38,7 +38,7 @@ av_cold void swri_audio_convert_init_x86(struct AudioConvert *ac,
                                  enum AVSampleFormat out_fmt,
                                  enum AVSampleFormat in_fmt,
                                  int channels){
-    int mm_flags = av_get_cpu_flags();
+    int mm_flags = av_cpu_get_flags();
 
     ac->simd_f= NULL;
 
diff --git a/libswresample/x86/rematrix_init.c b/libswresample/x86/rematrix_init.c
index e515e4bcff..9b944e1352 100644
--- a/libswresample/x86/rematrix_init.c
+++ b/libswresample/x86/rematrix_init.c
@@ -33,7 +33,7 @@ D(int16, sse2)
 
 av_cold int swri_rematrix_init_x86(struct SwrContext *s){
 #if HAVE_X86ASM
-    int mm_flags = av_get_cpu_flags();
+    int mm_flags = av_cpu_get_flags();
     int nb_in  = s->used_ch_count;
     int nb_out = s->out.ch_count;
     int num    = nb_in * nb_out;
diff --git a/libswresample/x86/resample_init.c b/libswresample/x86/resample_init.c
index 32c080ea4c..d04752a67d 100644
--- a/libswresample/x86/resample_init.c
+++ b/libswresample/x86/resample_init.c
@@ -48,7 +48,7 @@ RESAMPLE_FUNCS(double, fma3);
 
 av_cold void swri_resample_dsp_x86_init(ResampleContext *c)
 {
-    int av_unused mm_flags = av_get_cpu_flags();
+    int av_unused mm_flags = av_cpu_get_flags();
 
     switch(c->format){
     case AV_SAMPLE_FMT_S16P:
diff --git a/libswscale/swscale.c b/libswscale/swscale.c
index 61dfcb4dff..abf05f38e8 100644
--- a/libswscale/swscale.c
+++ b/libswscale/swscale.c
@@ -324,7 +324,7 @@ static int swscale(SwsContext *c, const uint8_t *src[],
         || srcStride[0]&15 || srcStride[1]&15 || srcStride[2]&15 || srcStride[3]&15
     ) {
         static int warnedAlready=0;
-        int cpu_flags = av_get_cpu_flags();
+        int cpu_flags = av_cpu_get_flags();
         if (HAVE_MMXEXT && (cpu_flags & AV_CPU_FLAG_SSE2) && !warnedAlready){
             av_log(c, AV_LOG_WARNING, "Warning: data is not aligned! This can lead to a speed loss\n");
             warnedAlready=1;
@@ -509,7 +509,7 @@ static int swscale(SwsContext *c, const uint8_t *src[],
     }
 
 #if HAVE_MMXEXT_INLINE
-    if (av_get_cpu_flags() & AV_CPU_FLAG_MMXEXT)
+    if (av_cpu_get_flags() & AV_CPU_FLAG_MMXEXT)
         __asm__ volatile ("sfence" ::: "memory");
 #endif
     emms_c();
diff --git a/libswscale/utils.c b/libswscale/utils.c
index 176fc6fd63..ead8747294 100644
--- a/libswscale/utils.c
+++ b/libswscale/utils.c
@@ -1192,7 +1192,7 @@ av_cold int sws_init_context(SwsContext *c, SwsFilter *srcFilter,
     static const float float_mult = 1.0f / 255.0f;
     static AVOnce rgb2rgb_once = AV_ONCE_INIT;
 
-    cpu_flags = av_get_cpu_flags();
+    cpu_flags = av_cpu_get_flags();
     flags     = c->flags;
     emms_c();
     if (ff_thread_once(&rgb2rgb_once, ff_sws_rgb2rgb_init) != 0)
diff --git a/libswscale/x86/rgb2rgb.c b/libswscale/x86/rgb2rgb.c
index c38a953277..fd02227c7c 100644
--- a/libswscale/x86/rgb2rgb.c
+++ b/libswscale/x86/rgb2rgb.c
@@ -156,7 +156,7 @@ void ff_uyvytoyuv422_avx(uint8_t *ydst, uint8_t *udst, uint8_t *vdst,
 
 av_cold void rgb2rgb_init_x86(void)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
 #if HAVE_INLINE_ASM
     if (INLINE_MMX(cpu_flags))
diff --git a/libswscale/x86/swscale.c b/libswscale/x86/swscale.c
index 0848a31461..5910c399cf 100644
--- a/libswscale/x86/swscale.c
+++ b/libswscale/x86/swscale.c
@@ -354,7 +354,7 @@ YUV2NV_DECL(nv21, avx2);
 
 av_cold void ff_sws_init_swscale_x86(SwsContext *c)
 {
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
 #if HAVE_MMX_INLINE
     if (INLINE_MMX(cpu_flags))
diff --git a/libswscale/x86/yuv2rgb.c b/libswscale/x86/yuv2rgb.c
index 47f45bd7c2..50ff8ddd38 100644
--- a/libswscale/x86/yuv2rgb.c
+++ b/libswscale/x86/yuv2rgb.c
@@ -69,7 +69,7 @@
 av_cold SwsFunc ff_yuv2rgb_init_x86(SwsContext *c)
 {
 #if HAVE_X86ASM
-    int cpu_flags = av_get_cpu_flags();
+    int cpu_flags = av_cpu_get_flags();
 
     if (EXTERNAL_SSSE3(cpu_flags)) {
         switch (c->dstFormat) {
diff --git a/libavutil/cpu.h b/libavutil/cpu.h
index c069076439..718c469b03 100644
--- a/libavutil/cpu.h
+++ b/libavutil/cpu.h
@@ -74,24 +74,24 @@
 
 /**
  * Return the flags which specify extensions supported by the CPU.
  * The returned value is affected by av_force_cpu_flags() if that was used
  * before. So av_get_cpu_flags() can easily be used in an application to
  * detect the enabled cpu flags.
  */
-int av_get_cpu_flags(void);
+int av_cpu_get_flags(void);
 
 /**
  * Disables cpu detection and forces the specified flags.
  * -1 is a special case that disables forcing of specific flags.
  */
-void av_force_cpu_flags(int flags);
+void av_cpu_force_flags(int flags);
 
 /**
  * Parse CPU caps from a string and update the given AV_CPU_* flags based on that.
  *
  * @return negative on error.
  */
-int av_parse_cpu_caps(unsigned *flags, const char *s);
+int av_cpu_parse_caps(unsigned *flags, const char *s);
 
 /**
  * @return the number of logical CPU cores present.
@@ -102,7 +102,7 @@ int av_cpu_count(void);
  * Overrides cpu count detection and forces the specified count.
  * Count < 1 disables forcing of specific count.
  */
-void av_force_cpu_count(int count);
+void av_cpu_force_count(int count);
 
 /**
  * Get the maximum data alignment that may be required by FFmpeg.
@@ -74,24 +74,24 @@
 /**
  * Return the flags which specify extensions supported by the CPU.
- * The returned value is affected by av_force_cpu_flags() if that was used
- * before. So av_get_cpu_flags() can easily be used in an application to
+ * The returned value is affected by av_cpu_force_flags() if that was used
+ * before. So av_cpu_get_flags() can easily be used in an application to
  * detect the enabled cpu flags.
  */
-- 
2.20.1 (Apple Git-117)



More information about the ffmpeg-devel mailing list